"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SitePages = void 0;
var web_1 = require("./web");
var utils_1 = require("../utils");
/**
 * Site Pages
 */
exports.SitePages = (function (url, targetInfo) {
    var sitePages = new utils_1.Base(targetInfo);
    // Default the properties
    sitePages.targetInfo.defaultToWebFl = true;
    sitePages.targetInfo.endpoint = "SitePages";
    // See if the web url exists
    if (url) {
        // Set the settings
        sitePages.targetInfo.url = url;
    }
    // Add the methods
    utils_1.Request.addMethods(sitePages, { __metadata: { type: "SP.Publishing.SitePageService" } });
    // Return the site pages
    return sitePages;
});
// Static method to create a modern page
exports.SitePages.createPage = (function (pageName, pageTitle, pageTemplate, url, targetInfo) {
    // Return a promise
    return new Promise(function (resolve, reject) {
        // Method called after the updates have completed
        var onComplete = function (itemId, fileUrl) {
            var web = web_1.Web(url, targetInfo);
            var results = { file: null, item: null, page: null };
            // Get the file
            web.getFileByUrl(fileUrl).query({ Select: ["*", "ListId"] }).execute(function (file) {
                // Set the file
                results.file = file;
                // Get the list
                web.Lists().getById(file.ListId).Items(itemId).execute(function (item) {
                    // Set the item
                    results.item = item;
                    // Get the page
                    exports.SitePages(url, targetInfo).Pages(itemId).execute(function (page) {
                        // Set the page
                        results.page = page;
                        // Resolve the request
                        resolve(results);
                    }, reject);
                }, reject);
            }, reject);
        };
        // Create the page
        exports.SitePages(url, targetInfo).Pages().createAppPage({
            Title: pageTitle,
            PageLayoutType: pageTemplate
        }).execute(function (page) {
            // Update the file name
            web_1.Web(url, targetInfo).Lists("Site Pages").Items(page.Id).update({
                FileLeafRef: pageName
            }).execute(
            // Updated the file name successfully
            function () {
                // Update the file url
                var idx = page.Url.lastIndexOf('/');
                var fileUrl = page.Url.substring(0, idx + 1) + pageName;
                // Complete the request
                onComplete(page.Id, fileUrl);
            }, 
            // Unable to update the file name, but still return the object
            function () {
                // Complete the request
                onComplete(page.Id, page.Url);
            });
        }, reject);
    });
});
